Skip to contents

Get Sample Rate

Usage

get_sample_rate(data, sample_rate = NULL, flag_estimated = FALSE)

Arguments

data

A data set of actigraphy/activity data

sample_rate

the sample rate. If this is not NULL, then it will be guess from the header or the data or the data separation

flag_estimated

if `TRUE`, then the output will have the attribute `"estimated"`, which is a logical indicated if it was found or estimated

Value

A length-1 numeric vector